@@ -1,4 +1,4 @@
-from os.path import join, sep as s, dirname
+from os.path import join, sep as s, dirname, expanduser
 import os
 import sys
 from textwrap import dedent
@@ -6,7 +6,8 @@ from textwrap import dedent
 import pytest
 
 from ..helpers import root_dir
-from jedi.api.helpers import start_match, fuzzy_match
+from jedi.api.helpers import _start_match, _fuzzy_match
+from jedi._compatibility import scandir
 
 
 def test_in_whitespace(Script):
@@ -21,7 +22,7 @@ def test_empty_init(Script):
     code = dedent('''\
     class X(object): pass
     X(''')
-    assert Script(code).complete()
+    assert not Script(code).complete()
 
 
 def test_in_empty_space(Script):
@@ -86,6 +87,18 @@ def test_loading_unicode_files_with_bad_global_charset(Script, monkeypatch, tmpd
     s.complete(line=2, column=4)
 
 
+def test_complete_expanduser(Script):
+    possibilities = scandir(expanduser('~'))
+    non_dots = [p for p in possibilities if not p.name.startswith('.') and len(p.name) > 1]
+    item = non_dots[0]
+    line = "'~%s%s'" % (os.sep, item.name)
+    s = Script(line)
+    expected_name = item.name
+    if item.is_dir():
+        expected_name += os.path.sep
+    assert expected_name in [c.name for c in s.complete(column=len(line)-1)]
+
+
 def test_fake_subnodes(Script):
     """
     Test the number of subnodes of a fake object.
@@ -286,6 +299,9 @@ current_dirname = os.path.basename(dirname(dirname(dirname(__file__))))
         (f2, os_path + 'join(["tes"]', 10, ['t' + s]),
         (f2, os_path + 'join(["tes"])', 10, ['t' + s]),
         (f2, os_path + 'join("test", "test_cac" + x,', 22, ['he.py']),
+
+        # GH #1528
+        (f2, "'a' 'b'", 4, Ellipsis),
     ]
 )
 def test_file_path_completions(Script, file, code, column, expected):
@@ -293,68 +309,72 @@ def test_file_path_completions(Script, file, code, column, expected):
     if isinstance(column, tuple):
         line, column = column
     comps = Script(code, path=file).complete(line=line, column=column)
-    if expected == "A LOT":
+    if expected is Ellipsis:
         assert len(comps) > 100  # This is basically global completions.
     else:
         assert [c.complete for c in comps] == expected
 
 
+def test_file_path_should_have_completions(Script):
+    assert Script('r"').complete()  # See GH #1503
+
+
 _dict_keys_completion_tests = [
-        ('ints[', 5, ['1', '50', Ellipsis]),
-        ('ints[]', 5, ['1', '50', Ellipsis]),
-        ('ints[1]', 5, ['1', '50', Ellipsis]),
-        ('ints[1]', 6, ['']),
-        ('ints[1', 5, ['1', '50', Ellipsis]),
-        ('ints[1', 6, ['']),
+    ('ints[', 5, ['1', '50', Ellipsis]),
+    ('ints[]', 5, ['1', '50', Ellipsis]),
+    ('ints[1]', 5, ['1', '50', Ellipsis]),
+    ('ints[1]', 6, ['']),
+    ('ints[1', 5, ['1', '50', Ellipsis]),
+    ('ints[1', 6, ['']),
 
-        ('ints[5]', 5, ['1', '50', Ellipsis]),
-        ('ints[5]', 6, ['0']),
-        ('ints[50', 5, ['1', '50', Ellipsis]),
-        ('ints[5', 6, ['0']),
-        ('ints[ 5', None, ['0']),
-        ('ints [ 5', None, ['0']),
-        ('ints[50', 6, ['0']),
-        ('ints[50', 7, ['']),
+    ('ints[5]', 5, ['1', '50', Ellipsis]),
+    ('ints[5]', 6, ['0']),
+    ('ints[50', 5, ['1', '50', Ellipsis]),
+    ('ints[5', 6, ['0']),
+    ('ints[ 5', None, ['0']),
+    ('ints [ 5', None, ['0']),
+    ('ints[50', 6, ['0']),
+    ('ints[50', 7, ['']),
 
-        ('strs[', 5, ["'asdf'", "'fbar'", "'foo'", Ellipsis]),
-        ('strs[]', 5, ["'asdf'", "'fbar'", "'foo'", Ellipsis]),
-        ("strs['", 6, ["asdf'", "fbar'", "foo'"]),
-        ("strs[']", 6, ["asdf'", "fbar'", "foo'"]),
-        ('strs["]', 6, ['asdf"', 'fbar"', 'foo"']),
-        ('strs["""]', 6, ['asdf', 'fbar', 'foo']),
-        ('strs["""]', 8, ['asdf"""', 'fbar"""', 'foo"""']),
-        ('strs[b"]', 8, []),
-        ('strs[r"asd', 10, ['f"']),
-        ('strs[r"asd"', 10, ['f']),
-        ('strs[R"asd', 10, ['f"']),
-        ('strs[ R"asd', None, ['f"']),
-        ('strs[\tR"asd', None, ['f"']),
-        ('strs[\nR"asd', None, ['f"']),
-        ('strs[f"asd', 10, []),
-        ('strs[br"""asd', 13, ['f"""']),
-        ('strs[br"""asd"""', 13, ['f']),
-        ('strs[ \t"""asd"""', 13, ['f']),
+    ('strs[', 5, ["'asdf'", "'fbar'", "'foo'", Ellipsis]),
+    ('strs[]', 5, ["'asdf'", "'fbar'", "'foo'", Ellipsis]),
+    ("strs['", 6, ["asdf'", "fbar'", "foo'"]),
+    ("strs[']", 6, ["asdf'", "fbar'", "foo'"]),
+    ('strs["]', 6, ['asdf"', 'fbar"', 'foo"']),
+    ('strs["""]', 6, ['asdf', 'fbar', 'foo']),
+    ('strs["""]', 8, ['asdf"""', 'fbar"""', 'foo"""']),
+    ('strs[b"]', 8, []),
+    ('strs[r"asd', 10, ['f"']),
+    ('strs[r"asd"', 10, ['f']),
+    ('strs[R"asd', 10, ['f"']),
+    ('strs[ R"asd', None, ['f"']),
+    ('strs[\tR"asd', None, ['f"']),
+    ('strs[\nR"asd', None, ['f"']),
+    ('strs[f"asd', 10, []),
+    ('strs[br"""asd', 13, ['f"""']),
+    ('strs[br"""asd"""', 13, ['f']),
+    ('strs[ \t"""asd"""', 13, ['f']),
 
-        ('strs["f', 7, ['bar"', 'oo"']),
-        ('strs["f"', 7, ['bar', 'oo']),
-        ('strs["f]', 7, ['bar"', 'oo"']),
-        ('strs["f"]', 7, ['bar', 'oo']),
+    ('strs["f', 7, ['bar"', 'oo"']),
+    ('strs["f"', 7, ['bar', 'oo']),
+    ('strs["f]', 7, ['bar"', 'oo"']),
+    ('strs["f"]', 7, ['bar', 'oo']),
 
-        ('mixed[', 6, [r"'a\\sdf'", '1', '1.1', "b'foo'", Ellipsis]),
-        ('mixed[1', 7, ['', '.1']),
-        ('mixed[Non', 9, ['e']),
+    ('mixed[', 6, [r"'a\\sdf'", '1', '1.1', "b'foo'", Ellipsis]),
+    ('mixed[1', 7, ['', '.1']),
+    ('mixed[Non', 9, ['e']),
 
-        ('casted["f', 9, ['3"', 'bar"', 'oo"']),
-        ('casted["f"', 9, ['3', 'bar', 'oo']),
-        ('casted["f3', 10, ['"']),
-        ('casted["f3"', 10, ['']),
-        ('casted_mod["f', 13, ['3"', 'bar"', 'oo"', 'ull"', 'uuu"']),
+    ('casted["f', 9, ['3"', 'bar"', 'oo"']),
+    ('casted["f"', 9, ['3', 'bar', 'oo']),
+    ('casted["f3', 10, ['"']),
+    ('casted["f3"', 10, ['']),
+    ('casted_mod["f', 13, ['3"', 'bar"', 'oo"', 'ull"', 'uuu"']),
 
-        ('keywords["', None, ['a"']),
-        ('keywords[Non', None, ['e']),
-        ('keywords[Fa', None, ['lse']),
-        ('keywords[Tr', None, ['ue']),
-        ('keywords[str', None, ['', 's']),
+    ('keywords["', None, ['a"']),
+    ('keywords[Non', None, ['e']),
+    ('keywords[Fa', None, ['lse']),
+    ('keywords[Tr', None, ['ue']),
+    ('keywords[str', None, ['', 's']),
 ]
 
 
@@ -374,8 +394,7 @@ def test_dict_keys_completions(Script, added_code, column, expected, skip_pre_py
         casted_mod["full"] = 8
         keywords = {None: 1, False: 2, "a": 3}
         ''')
-    line = None
-    comps = Script(code + added_code).complete(line=line, column=column)
+    comps = Script(code + added_code).complete(column=column)
     if Ellipsis in expected:
         # This means that global completions are part of this, so filter all of
         # that out.
@@ -385,16 +404,21 @@ def test_dict_keys_completions(Script, added_code, column, expected, skip_pre_py
     assert [c.complete for c in comps] == expected
 
 
+@pytest.mark.skipif(sys.version_info[0] == 2, reason="Ignore Python 2, because EOL")
+def test_dict_keys_in_weird_case(Script, skip_pre_python36):
+    assert Script('a[\n# foo\nx]').complete(line=2, column=0)
+
+
 def test_start_match():
-    assert start_match('Condition', 'C')
+    assert _start_match('Condition', 'C')
 
 
 def test_fuzzy_match():
-    assert fuzzy_match('Condition', 'i')
-    assert not fuzzy_match('Condition', 'p')
-    assert fuzzy_match('Condition', 'ii')
-    assert not fuzzy_match('Condition', 'Ciito')
-    assert fuzzy_match('Condition', 'Cdiio')
+    assert _fuzzy_match('Condition', 'i')
+    assert not _fuzzy_match('Condition', 'p')
+    assert _fuzzy_match('Condition', 'ii')
+    assert not _fuzzy_match('Condition', 'Ciito')
+    assert _fuzzy_match('Condition', 'Cdiio')
 
 
 def test_ellipsis_completion(Script):
@@ -431,8 +455,9 @@ def test_completion_cache(Script, module_injector):
     assert cls.docstring() == 'foo()\n\ndoc2'
 
 
-def test_typing_module_completions(Script):
-    for c in Script('import typing; typing.').completions():
+@pytest.mark.parametrize('module', ['typing', 'os'])
+def test_module_completions(Script, module):
+    for c in Script('import {module}; {module}.'.format(module=module)).complete():
         # Just make sure that there are no errors
         c.type
         c.docstring()
