@@ -422,6 +422,39 @@ def test_decorator(Script):
     assert d.docstring(raw=True) == 'Nice docstring'
 
 
+def test_method_decorator(Script, skip_pre_python35):
+    code = dedent('''
+        def decorator(func):
+            @wraps(func)
+            def wrapper(*args, **kwargs):
+                """wrapper docstring"""
+                return func(*args, **kwargs)
+            return wrapper
+
+        class Foo():
+            @decorator
+            def check_user(self, f):
+                """Nice docstring"""
+                pass
+
+        Foo().check_user''')
+
+    d, = Script(code).infer()
+    assert d.docstring() == 'wrapper(f)\n\nNice docstring'
+
+
+def test_partial(Script, skip_pre_python36):
+    code = dedent('''
+        def foo():
+            'x y z'
+        from functools import partial
+        x = partial(foo)
+        x''')
+
+    for p in Script(code).infer():
+        assert p.docstring(raw=True) == 'x y z'
+
+
 def test_basic_str_init_signature(Script, disable_typeshed):
     # See GH #1414 and GH #1426
     code = dedent('''
