@@ -5,7 +5,7 @@ except ImportError:
 
 from jedi import utils
 
-from .helpers import unittest, cwd_at
+from .helpers import unittest
 
 
 @unittest.skipIf(not readline, "readline not found")
@@ -80,15 +80,16 @@ class TestSetupReadline(unittest.TestCase):
         difference = {
             x for x in difference
             if all(not x.startswith('from os import ' + s)
-                   for s in ['_', 'O_', 'EX_', 'MFD_', 'SF_', 'ST_'])
+                   for s in ['_', 'O_', 'EX_', 'MFD_', 'SF_', 'ST_',
+                             'CLD_', 'POSIX_SPAWN_', 'P_', 'RWF_',
+                             'SCHED_'])
         }
         # There are quite a few differences, because both Windows and Linux
         # (posix and nt) librariesare included.
-        assert len(difference) < 20
+        assert len(difference) < 15
 
-    @cwd_at('test')
     def test_local_import(self):
-        s = 'import test_utils'
+        s = 'import test.test_utils'
         assert self.complete(s) == [s]
 
     def test_preexisting_values(self):
